@@ -1,9 +1,7 @@
 import re
 import logging
-from .settings import get_active_settings
 import jwt
 
-herre_settings = get_active_settings()
 
 
 logger = logging.getLogger(__name__)
